@@ -102,7 +102,11 @@ class RIMEClient:
     _throttler = ThrottleQueue(desired_events_per_epoch=20, epoch_duration_sec=300)
 
     def __init__(
-        self, domain: str, api_key: str = "", channel_timeout: float = 5.0
+        self,
+        domain: str,
+        api_key: str = "",
+        channel_timeout: float = 5.0,
+        disable_tls: bool = False,
     ) -> None:
         """Create a new RIMEClient connected to the services available at `domain`.
 
@@ -114,13 +118,22 @@ class RIMEClient:
             channel_timeout: float
                 The amount of time in seconds to wait for channels to become ready
                 when opening connections to gRPC servers.
+            disable_tls: bool
+                Whether to disable tls when connecting to the backend.
 
         Raises:
             ValueError
                 If a connection cannot be made to a backend service within `timeout`.
         """
         self._domain = domain
-        self._backend = RIMEBackend(domain, api_key, channel_timeout=channel_timeout)
+        if disable_tls:
+            print(
+                "WARNING: disabling tls is not recommended."
+                " Please ensure you are on a secure connection to your servers."
+            )
+        self._backend = RIMEBackend(
+            domain, api_key, channel_timeout=channel_timeout, disable_tls=disable_tls
+        )
 
     def __str__(self) -> str:
         """Pretty-print the object."""
