@@ -3,10 +3,13 @@
 from typing import Any, Callable, Generic, Optional, TypeVar
 
 import grpc
+from deprecated import deprecated
 
-from rime_sdk.protos.continuous.continuous_pb2_grpc import CTServiceStub
+from rime_sdk.protos.file_upload.file_upload_pb2_grpc import FileUploadStub
+from rime_sdk.protos.firewall.firewall_pb2_grpc import FirewallServiceStub
 from rime_sdk.protos.image_registry.image_registry_pb2_grpc import ImageRegistryStub
 from rime_sdk.protos.model_testing.model_testing_pb2_grpc import ModelTestingStub
+from rime_sdk.protos.project.project_pb2_grpc import ProjectManagerStub
 from rime_sdk.protos.results_upload.results_upload_pb2_grpc import ResultsStoreStub
 from rime_sdk.protos.test_run_results.test_run_results_pb2_grpc import ResultsReaderStub
 from rime_sdk.protos.test_run_tracker.test_run_tracker_pb2_grpc import (
@@ -16,6 +19,7 @@ from rime_sdk.protos.test_run_tracker.test_run_tracker_pb2_grpc import (
 # Generic type representing a client stub for a gRPC server.
 C = TypeVar("C")
 
+
 # GrpcApiKeyAuth is an AuthMetadataPlugin to add api key in header on all calls
 class GrpcApiKeyAuth(grpc.AuthMetadataPlugin):
     """Auth plugin to add 'rime-api-key' header to grpc calls."""
@@ -43,6 +47,7 @@ class RIMEConnection(Generic[C]):
         addr: str,
         api_key: str,
         channel_timeout: float = 5.0,
+        disable_tls: bool = False,
     ) -> None:
         """Create a new connection for a RIME backend.
 
@@ -56,12 +61,15 @@ class RIMEConnection(Generic[C]):
                 Api Key to validate RIME grpc requests with.
             channel_timeout: float
                 The timeout in seconds for waiting for the given channel.
+            disable_tls: bool
+                Whether to disable tls when connecting to the backend.
         """
         self._create_backend_fn = create_backend_fn
         self._api_key = api_key
         self._addr = addr
         self._channel_timeout = channel_timeout
         self._channel: Optional[grpc.Channel] = None
+        self._disable_tls = disable_tls
 
     def __enter__(self) -> C:
         """Acquires the channel created in the with-context."""
@@ -84,7 +92,7 @@ class RIMEConnection(Generic[C]):
         if self._channel:
             self._channel.close()
 
-    def _build_and_validate_channel(self, addr: str, timeout: float) -> grpc.Channel:
+    def _build_and_validate_channel(self, addr: str, timeout: float,) -> grpc.Channel:
         """Build and validate a secure gRPC channel at `addr`.
 
         Args:
@@ -99,11 +107,14 @@ class RIMEConnection(Generic[C]):
         """
         try:
             # create credentials
-            credentials = grpc.composite_channel_credentials(
-                self._get_ssl_channel_credentials(),
-                grpc.metadata_call_credentials(GrpcApiKeyAuth(self._api_key)),
-            )
-            channel = grpc.secure_channel(addr, credentials)
+            if self._disable_tls:
+                channel = grpc.insecure_channel(addr)
+            else:
+                credentials = grpc.composite_channel_credentials(
+                    self._get_ssl_channel_credentials(),
+                    grpc.metadata_call_credentials(GrpcApiKeyAuth(self._api_key)),
+                )
+                channel = grpc.secure_channel(addr, credentials)
             grpc.channel_ready_future(channel).result(timeout=timeout)
             return channel
         except grpc.FutureTimeoutError:
@@ -117,135 +128,129 @@ class RIMEConnection(Generic[C]):
 class RIMEBackend:
     """An abstraction for connecting to RIME's backend services."""
 
-    def __init__(self, domain: str, api_key: str = "", channel_timeout: float = 5.0):
+    def __init__(
+        self,
+        domain: str,
+        api_key: str = "",
+        channel_timeout: float = 5.0,
+        disable_tls: bool = False,
+    ):
         """Create a new RIME backend.
 
         Args:
             domain: str
-                The base domain/address of the RIME service.+
+                The backend domain/address of the RIME service.
             api_key: str
                 The api key providing authentication to RIME services
             channel_timeout: float
                 The amount of time in seconds to wait for channels to become ready
                 when opening connections to gRPC servers.
+            disable_tls: bool
+                Whether to disable tls when connecting to the backend.
         """
         self._channel_timeout = channel_timeout
         self._api_key = api_key
+        self._disable_tls = disable_tls
         domain_split = domain.split(".", 1)
-        if domain_split[0][-4:] != "rime":
-            raise ValueError("The configuration must be a valid rime webapp url")
-        base_domain = domain_split[1]
-        self._image_registry_addr = self._get_image_registry_addr(base_domain)
-        self._model_testing_addr = self._get_model_testing_addr(base_domain)
-        self._results_store_addr = self._get_results_store_addr(base_domain)
-        self._test_run_tracker_addr = self._get_test_run_tracker_addr(base_domain)
-        self._test_run_results_addr = self._get_test_run_results_addr(base_domain)
-        self._grpc_web_addr = self._get_continuous_addr(base_domain)
+        if domain_split[0][-4:] == "rime":
+            base_domain = domain_split[1]
+            domain = "rime-backend." + base_domain
+        self._backend_addr = self._get_backend_addr(domain, disable_tls)
 
-    def _get_image_registry_addr(self, domain: str) -> str:
-        """Construct an address to the image-registry service from `domain`.
+    def _get_backend_addr(self, domain: str, disable_tls: bool = False) -> str:
+        """Construct an address to the all backend services from `domain`.
 
         Args:
             domain: str
-                The base domain/address of the RIME service.
+                The backend domain/address of the RIME service.
+            disable_tls: bool
+                Whether to disable tls when connecting to the backend.
         """
-        return f"rime-image-registry.{domain}:443"
+        if disable_tls:
+            return f"{domain}:80"
+        return f"{domain}:443"
 
-    def _get_model_testing_addr(self, domain: str) -> str:
-        """Construct an address to the model-testing service from `domain`.
-
-        Args:
-            domain: str
-                The base domain/address of the RIME service.
-        """
-        return f"rime-modeltesting.{domain}:443"
-
-    def _get_results_store_addr(self, domain: str) -> str:
-        """Construct an address to the results store service from `domain`.
-
-        Args:
-            domain: str
-                The base domain/address of the RIME service.
-        """
-        return f"rime-results-store.{domain}:443"
-
-    def _get_test_run_tracker_addr(self, domain: str) -> str:
-        """Construct an address to the test-run-tracker service from `domain`.
-
-        Args:
-            domain: str
-                The base domain/address of the RIME service.
-        """
-        return f"rime-test-run-tracker.{domain}:443"
-
-    def _get_test_run_results_addr(self, domain: str) -> str:
-        """Construct an address to the test-run-results service from `domain`.
-
-        Args:
-            domain: str
-                The base domain/address of the RIME service.
-        """
-        return f"rime-test-run-results.{domain}:443"
-
-    def _get_continuous_addr(self, domain: str) -> str:
-        """Construct an address to the continuous service from `domain`.
-
-        Args:
-            domain: str
-                The base domain/address of the RIME service.
-        """
-        return f"rime-continuous.{domain}:443"
+    def get_file_upload_stub(self) -> RIMEConnection[FileUploadStub]:
+        """Return a file upload client."""
+        # Note: the file upload service is currently co-located with the
+        # data-manager until the file upload service is replaced.
+        return RIMEConnection[FileUploadStub](
+            FileUploadStub,
+            self._backend_addr,
+            self._api_key,
+            channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
+        )
 
     def get_image_registry_stub(self) -> RIMEConnection[ImageRegistryStub]:
         """Return an image registry client."""
         return RIMEConnection[ImageRegistryStub](
             ImageRegistryStub,
-            self._image_registry_addr,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
 
     def get_model_testing_stub(self) -> RIMEConnection[ModelTestingStub]:
         """Return a model testing client."""
         return RIMEConnection[ModelTestingStub](
             ModelTestingStub,
-            self._model_testing_addr,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
 
+    @deprecated(
+        version="0.15.0", reason="Use `get_test_run_results_stub()` instead",
+    )
     def get_result_store_stub(self) -> RIMEConnection[ResultsStoreStub]:
         """Return a result store client."""
         return RIMEConnection[ResultsStoreStub](
             ResultsStoreStub,
-            self._results_store_addr,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
 
     def get_test_run_tracker_stub(self) -> RIMEConnection[TestRunTrackerStub]:
         """Return a test run tracker client."""
         return RIMEConnection[TestRunTrackerStub](
             TestRunTrackerStub,
-            self._test_run_tracker_addr,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
 
     def get_test_run_results_stub(self) -> RIMEConnection[ResultsReaderStub]:
         """Return a test run results reader client."""
         return RIMEConnection[ResultsReaderStub](
             ResultsReaderStub,
-            self._test_run_results_addr,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
 
-    def get_continuous_testing_stub(self) -> RIMEConnection[CTServiceStub]:
-        """Return a continuous testing client."""
-        return RIMEConnection[CTServiceStub](
-            CTServiceStub,
-            self._grpc_web_addr,
+    def get_firewall_stub(self) -> RIMEConnection[FirewallServiceStub]:
+        """Return a firewall client."""
+        return RIMEConnection[FirewallServiceStub](
+            FirewallServiceStub,
+            self._backend_addr,
             self._api_key,
             channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
+        )
+
+    def get_project_manager_stub(self) -> RIMEConnection[ProjectManagerStub]:
+        """Return a project management client."""
+        return RIMEConnection[ProjectManagerStub](
+            ProjectManagerStub,
+            self._backend_addr,
+            self._api_key,
+            channel_timeout=self._channel_timeout,
+            disable_tls=self._disable_tls,
         )
